dojo.provide("com.ibm.pb.localized.DojoLocalized");

dojo.require("dojo.i18n");
dojo.require("com.ibm.pb.logging.Loggable");

dojo.declare("com.ibm.pb.localized.DojoLocalized", [com.ibm.mashups.enabler.Localized, com.ibm.pb.logging.Loggable], {
	/**
	 * Defines the package where the resource bundle for this item exists
	 * @type String
	 */
	bundlePackage: "",
	
	/**
	 * Defines the name of resource bundle for this item
	 * @type String
	 */
	bundleName: "",
	
	/**
	 * Defines the key to use to look up the title and description in the resource bundle.
	 * The title is mapped to the "bundleKey.title" property and the description is mapped to the
	 * "bundleKey.description" property in the resource bundle.
	 * @type String
	 */
	bundleKey: "",
	
	constructor: function(jsonObj) {
		this.bundlePackage = jsonObj.bundlePackage;
		this.bundleName = jsonObj.bundleName;
		this.bundleKey = jsonObj.bundleKey;
		this._locales = [dojo.locale];
		var extra = dojo.config && dojo.config.extraLocale;
		if(extra) {this._locales.push.apply(this._locales, extra);}
		// avoid build process picking this up... then failing; jslint complains, but its required
		dojo["require" + "Localization"](this.bundlePackage, this.bundleName);
	},
	_getBundle: function(locale) {
		var mname = "_getBundle", ret = {};
		try {
			ret = dojo.i18n.getLocalization(this.bundlePackage, this.bundleName, locale);
			this.LOGGER.trace(mname, "Found bundle for locale ${0}", [locale]);
		} catch(err) {
			// no-op, just return {}
			// must catch this per the API spec, instead of propagating to the caller
			this.LOGGER.warning("_getBundle", "Bundle not found for locale ${0}", [locale]);
		}
		return ret;
	},
	getLocales: function() {
		var mname = "getLocales";
		this.LOGGER.entering(mname, []);
		if(!this._locales.filtered) {
			this.LOGGER.trace(mname, "Filtering locales", []);
			// filter the locales list to only those locales where a title OR description exist
			// for this localized instance in the bundle
			this._locales = dojo.filter(this._locales, function(locale){
				var bundle = this._getBundle(locale);
				var ret = bundle[this.bundleKey] || 
					bundle[this.bundleKey + "_title"] || 
					bundle[this.bundleKey + "_description"];
				this.LOGGER.trace(mname, "Does title or description exist for locale ${0}? ${1}", [locale, ret]);
				return ret;
			}, this);
			this._locales.filtered = true;
		}
		this.LOGGER.exiting(mname, [this._locales]);
		return this._locales;
	},
	getTitle: function(locale) {
		var mname = "getTitle";
		this.LOGGER.entering(mname, [locale]);
		var bundle = this._getBundle(locale);
		var ret = bundle[this.bundleKey + "_title"] || bundle[this.bundleKey];
		this.LOGGER.exiting(mname, [locale]);
		return ret;
	},
	getDescription: function(locale) {
		var mname = "getDescription";
		this.LOGGER.entering(mname, [locale]);
		var ret = this._getBundle(locale)[this.bundleKey + "_description"];
		this.LOGGER.exiting(mname, [locale]);
		return ret;
	}
});